diff plugin/LADSPAPluginFactory.cpp @ 1885:1adbeb52d761

Make some debug output less obvious
author Chris Cannam
date Fri, 14 Aug 2020 10:42:37 +0100
parents 5f8fbbde08ff
children
line wrap: on
line diff
--- a/plugin/LADSPAPluginFactory.cpp	Tue Jul 21 13:59:29 2020 +0100
+++ b/plugin/LADSPAPluginFactory.cpp	Fri Aug 14 10:42:37 2020 +0100
@@ -81,7 +81,7 @@
         const LADSPA_Descriptor *descriptor = getLADSPADescriptor(*i);
 
         if (!descriptor) {
-            cerr << "WARNING: LADSPAPluginFactory::enumeratePlugins: couldn't get descriptor for identifier " << *i << endl;
+            SVCERR << "WARNING: LADSPAPluginFactory::enumeratePlugins: couldn't get descriptor for identifier " << *i << endl;
             continue;
         }
         
@@ -95,11 +95,11 @@
         list.push_back("false"); // is grouped
 
         if (m_taxonomy.find(*i) != m_taxonomy.end() && m_taxonomy[*i] != "") {
-//                cerr << "LADSPAPluginFactory: cat for " << *i << " found in taxonomy as " << m_taxonomy[descriptor->UniqueID] << endl;
+//                SVCERR << "LADSPAPluginFactory: cat for " << *i << " found in taxonomy as " << m_taxonomy[descriptor->UniqueID] << endl;
             list.push_back(m_taxonomy[*i]);
         } else {
             list.push_back("");
-//                cerr << "LADSPAPluginFactory: cat for " << *i << " not found (despite having " << m_fallbackCategories.size() << " fallbacks)" << endl;
+//                SVCERR << "LADSPAPluginFactory: cat for " << *i << " not found (despite having " << m_fallbackCategories.size() << " fallbacks)" << endl;
             
         }
 
@@ -618,7 +618,7 @@
         QDir dir(lrdfPaths[i], "*.rdf;*.rdfs");
         for (unsigned int j = 0; j < dir.count(); ++j) {
             if (!lrdf_read_file(QString("file:" + lrdfPaths[i] + "/" + dir[j]).toStdString().c_str())) {
-//                cerr << "LADSPAPluginFactory: read RDF file " << (lrdfPaths[i] + "/" + dir[j]) << endl;
+//                SVCERR << "LADSPAPluginFactory: read RDF file " << (lrdfPaths[i] + "/" + dir[j]) << endl;
                 haveSomething = true;
             }
         }
@@ -645,7 +645,7 @@
     void *libraryHandle = DLOPEN(soname, RTLD_LAZY);
 
     if (!libraryHandle) {
-        cerr << "WARNING: LADSPAPluginFactory::discoverPlugins: couldn't load plugin library "
+        SVCERR << "WARNING: LADSPAPluginFactory::discoverPlugins: couldn't load plugin library "
                   << soname << " - " << DLERROR() << endl;
         return;
     }
@@ -654,7 +654,7 @@
         DLSYM(libraryHandle, "ladspa_descriptor");
 
     if (!fn) {
-        cerr << "WARNING: LADSPAPluginFactory::discoverPlugins: No descriptor function in " << soname << endl;
+        SVCERR << "WARNING: LADSPAPluginFactory::discoverPlugins: No descriptor function in " << soname << endl;
         return;
     }
 
@@ -684,7 +684,7 @@
                 
         if (m_lrdfTaxonomy[descriptor->UniqueID] != "") {
             m_taxonomy[identifier] = m_lrdfTaxonomy[descriptor->UniqueID];
-//            cerr << "set id \"" << identifier << "\" to cat \"" << m_taxonomy[identifier] << "\" from LRDF" << endl;
+//            SVCERR << "set id \"" << identifier << "\" to cat \"" << m_taxonomy[identifier] << "\" from LRDF" << endl;
 //            cout << identifier << "::" << m_taxonomy[identifier] << endl;
         }
 
@@ -701,7 +701,7 @@
         
         rtd.category = category.toStdString();
 
 //        cerr << "Plugin id is " << descriptor->UniqueID
 //                  << ", category is \"" << (category ? category : QString("(none)"))
 //                  << "\", name is " << descriptor->Name
 //                  << ", label is " << descriptor->Label
@@ -722,7 +722,7 @@
                     
                     for (unsigned int j = 0; j < defs->count; j++) {
                         if (defs->items[j].pid == controlPortNumber) {
-//                            cerr << "Default for this port (" << defs->items[j].pid << ", " << defs->items[j].label << ") is " << defs->items[j].value << "; applying this to port number " << i << " with name " << descriptor->PortNames[i] << endl;
+//                            SVCERR << "Default for this port (" << defs->items[j].pid << ", " << defs->items[j].label << ") is " << defs->items[j].value << "; applying this to port number " << i << " with name " << descriptor->PortNames[i] << endl;
                             m_portDefaults[descriptor->UniqueID][i] =
                                 defs->items[j].value;
                         }
@@ -765,7 +765,7 @@
     }
 
     if (DLCLOSE(libraryHandle) != 0) {
-        cerr << "WARNING: LADSPAPluginFactory::discoverPlugins - can't unload " << libraryHandle << endl;
+        SVCERR << "WARNING: LADSPAPluginFactory::discoverPlugins - can't unload " << libraryHandle << endl;
         return;
     }
 }
@@ -701,7 +701,7 @@
         rtd.category = category.toStdString();
 
-//        cerr << "Plugin id is " << descriptor->UniqueID
+//        SVCERR << "Plugin id is " << descriptor->UniqueID
 //                  << ", category is \"" << (category ? category : QString("(none)"))
 //                  << "\", name is " << descriptor->Name